#!/bin/bash

#   postfix-mysql.sh - generate an SQL file that will be use to create
#   all the required tables and stuff for the email server
#
#   DISS - Debian Install Server Scripts
#   A set of scripts to automate installation of Servers on Debian
#   (c) 2009 Emmanuel Revah - manu-at-manurevah.com
#
#   This file is part of DISS.
#
#   DISS is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   DISS is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with DISS.  If not, see <http://www.gnu.org/licenses/>.

echo "
-- Install Mysql Part of DISS Email server 
-- based on workaround.org ISP style email server

-- create mailuser who can only consult database

GRANT SELECT ON mailserver.* TO mailuser@localhost IDENTIFIED BY '${MAILUSERPASS}';

GRANT SELECT , INSERT , UPDATE , DELETE , CREATE , DROP , INDEX , ALTER , 
CREATE TEMPORARY TABLES , CREATE VIEW , SHOW VIEW , CREATE
ROUTINE, ALTER ROUTINE, EXECUTE ON mailserver . * TO 'mailadmin'@'localhost'
IDENTIFIED BY '${MAILADMINPASS}';

FLUSH PRIVILEGES ;

-- create tables (base part of mail server)

USE mailserver;

CREATE TABLE virtual_domains (
id INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
name VARCHAR(50) NOT NULL
) ENGINE = InnoDB;

CREATE TABLE virtual_users (
id int(11) NOT NULL AUTO_INCREMENT PRIMARY KEY,
domain_id INT(11) NOT NULL,
user VARCHAR(40) NOT NULL,
password VARCHAR(32) NOT NULL,
policy_id int(11) NOT NULL default '2',
CONSTRAINT UNIQUE_EMAIL UNIQUE (domain_id,user),
FOREIGN KEY (domain_id) REFERENCES virtual_domains(id) ON DELETE CASCADE
) ENGINE = InnoDB;

CREATE TABLE virtual_aliases (
id int(11) NOT NULL AUTO_INCREMENT PRIMARY KEY,
domain_id INT(11) NOT NULL,
source VARCHAR(20) NOT NULL,
destination VARCHAR(80) NOT NULL,
FOREIGN KEY (domain_id) REFERENCES virtual_domains(id) ON DELETE CASCADE
) ENGINE = InnoDB;

-- view_users is modified from the workaround tutorial

CREATE VIEW view_users AS
SELECT virtual_users.id, CONCAT(virtual_users.user, '@', virtual_domains.name) AS email, virtual_users.password, virtual_users.policy_id
FROM virtual_users
LEFT JOIN virtual_domains ON virtual_users.domain_id=virtual_domains.id;

CREATE VIEW view_aliases AS
SELECT CONCAT(virtual_aliases.source, '@', virtual_domains.name) AS email, destination
FROM virtual_aliases
LEFT JOIN virtual_domains ON virtual_aliases.domain_id=virtual_domains.id; 

-- insert ${MAILDOMAIN} into table domain 

INSERT INTO virtual_domains (id, name) VALUES (1, '${MAILDOMAIN}');
INSERT INTO virtual_users (id, domain_id, user, password) VALUES (1, 1, '${MAILADMINUSER}', MD5('${MAILADMINUSERPASS}'));
INSERT INTO virtual_aliases (id, domain_id, source, destination) VALUES (1, 1, 'postmaster', '${MAILADMINUSER}@${MAILDOMAIN}'),
(2, 1, 'webmaster', '${MAILADMINUSER}@${MAILDOMAIN}');

-- create policy table

CREATE TABLE policy (
  id int(10) unsigned NOT NULL auto_increment,
  policy_name varchar(255) default NULL,
  virus_lover char(1) default 'Y',
  spam_lover char(1) default 'Y',
  banned_files_lover char(1) default 'Y',
  bad_header_lover char(1) default 'Y',
  bypass_virus_checks char(1) default 'Y',
  bypass_spam_checks char(1) default 'Y',
  bypass_banned_checks char(1) default 'Y',
  bypass_header_checks char(1) default 'Y',
  discard_viruses char(1) default 'N',
  discard_spam char(1) default 'N',
  discard_banned_files char(1) default 'N',
  discard_bad_headers char(1) default 'N',
  spam_modifies_subj char(1) default 'N',
  spam_quarantine_to varchar(64) default NULL,
  spam_tag_level float default '999',
  spam_tag2_level float default '999',
  spam_kill_level float default '999',
  PRIMARY KEY  (id)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1;

-- Create some policies, 'none' and 'all', for no checks and all checks

INSERT INTO policy (id, policy_name, virus_lover, spam_lover, banned_files_lover, bad_header_lover, bypass_virus_checks, bypass_spam_checks, bypass_banned_checks, bypass_header_checks, spam_modifies_subj, spam_quarantine_to, spam_tag_level, spam_tag2_level, spam_kill_level) VALUES
(1, 'none', 'Y', 'Y', 'Y', 'Y', 'Y', 'Y', 'Y', 'Y', 'N', NULL, 100, 1000, 10000),
(2, 'all', 'N', 'N', 'N', 'N', 'N', 'N', 'N', 'N', 'Y', NULL, -50, 4, 10);

-- create tables for vmail manager

CREATE TABLE domain_admins (
id int(11) NOT NULL auto_increment,
domain_id int(11) NOT NULL,
user_id int(11) NOT NULL,
PRIMARY KEY  (id)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

CREATE TABLE languages (
id int(3) NOT NULL auto_increment,
name varchar(50) NOT NULL,
active tinyint(1) NOT NULL,
PRIMARY KEY  (id)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=3 ;

CREATE TABLE text (
id int(10) NOT NULL auto_increment,
mid int(10) NOT NULL,
language_id int(3) NOT NULL,
text longtext NOT NULL,
  PRIMARY KEY  (id)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=123 ;


-- insert data for vmail manager -- 

INSERT INTO languages (id, name, active) VALUES 
(1, 'English', 1),
(2, 'Deutsch', 1);

INSERT INTO text (id, mid, language_id, text) VALUES 
(1, 1, 1, 'Email adress'),
(2, 1, 2, 'Email Adresse'),
(3, 2, 1, 'Password'),
(4, 2, 2, 'Passwort'),
(5, 3, 1, 'is logged in as'),
(6, 3, 2, 'ist eingeloggt als'),
(7, 4, 1, 'No domain name.'),
(8, 4, 2, 'Kein Domainname angegeben.'),
(9, 5, 1, 'Domain name is not valid. Please check the rules for domain names.'),
(10, 5, 2, 'Domainname ist ungültig. Überprüfen Sie die Regeln für Domainnamen.'),
(11, 6, 1, 'Domain name did not change.'),
(12, 6, 2, 'Domainname wurde nicht verändert.'),
(13, 7, 1, 'New domain name '),
(14, 7, 2, 'Neuer Domainname '),
(15, 8, 1, ' is not valid. Please check the rules for domain names.'),
(16, 8, 2, ' ist ungültig. Überprüfen Sie die Regeln für Domainnamen.'),
(17, 9, 1, 'A virtual domain with this name already exists in the database.'),
(18, 9, 2, 'Eine virtuelle Domain mit diesem Namen existiert bereits in der Datenbank.'),
(19, 10, 1, 'No name for new virtual user.'),
(20, 10, 2, 'Kein Name für den neuen virtuellen Benutzer angegeben.'),
(21, 11, 1, 'New name '),
(22, 11, 2, 'Neuer Name '),
(23, 12, 1, ' is not valid. Please check the rules for names in email addresses.'),
(24, 12, 2, ' ist ungültig. Überprüfen Sie die Regeln für die Bezeichnung von Emailadressen.'),
(25, 13, 1, 'Password '),
(26, 13, 2, 'Passwort '),
(27, 14, 1, ' is not valid. Please check the rules for passwords.'),
(28, 14, 2, ' ist nicht gültig. Bitte überprüfen Sie die Regeln für Passwörter.'),
(29, 15, 1, 'A virtual user with this name already exists in this domain.'),
(30, 15, 2, 'Ein virtueller Benutzer mit diesem Namen existiet bereits in der Domain.'),
(31, 16, 1, 'No name for new virtual user.'),
(32, 16, 2, 'Kein Nae für den neuen, virtuellen Benutzer angegeben.'),
(33, 17, 1, 'No password for new virtual user.'),
(34, 17, 2, 'Kein Passwort für den neuen, virtuellen Benutzer angegeben.'),
(35, 18, 1, 'Really delete virtual domain '),
(36, 18, 2, 'Soll die Domain '),
(37, 19, 1, ' Users of this virtual domain also will be deleted recursivly.'),
(38, 19, 2, 'wirklich gelöscht werden? Dabei werden alle virtuellen Benutzer dieser Domain ebenfalls gelöscht.'),
(39, 20, 1, 'Really delete user: '),
(40, 20, 2, 'Benutzer wirklich löschen:'),
(41, 21, 1, 'Really save changes to virtual domain'),
(42, 21, 2, 'Änderungen wirklich speichern bei Domain'),
(43, 22, 1, 'Users adresses of this virtual domain also will be changed recursivly.'),
(44, 22, 2, 'Die Benutzeradressen werden dabei ebenfalls rekursiv angepasst.'),
(45, 23, 1, 'Manage virtual domains'),
(46, 23, 2, 'Virtuelle Domains verwalten'),
(47, 24, 1, 'Manage virtual users'),
(48, 24, 2, 'Virtuelle Benutzer verwalten'),
(49, 25, 1, 'Virtual Domain Manager'),
(50, 25, 2, 'Verwaltung virtueller Domains'),
(51, 26, 1, 'Number of domains:'),
(52, 26, 2, 'Anzahl Domains:'),
(53, 27, 1, 'Number of users:'),
(54, 27, 2, 'Anzahl Benutzer:'),
(55, 28, 1, 'Add new virtual domain'),
(56, 28, 2, 'Virtuelle Domain hinzufügen'),
(57, 29, 1, 'New virtual domain'),
(58, 29, 2, 'Neue virtuelle Domain'),
(59, 30, 1, 'Name of domain (FQDN):'),
(60, 30, 2, 'Name der Domain (FQDN):'),
(61, 31, 1, 'Save new virtual domain'),
(62, 31, 2, 'Neue virtuelle Domain speichern'),
(63, 32, 1, 'with validation of name'),
(64, 32, 2, 'mit Überprüfung des Namens'),
(65, 33, 1, 'Virtual domain list'),
(66, 33, 2, 'Liste virtueller Domains'),
(67, 34, 1, 'Action'),
(68, 34, 2, 'Aktion'),
(69, 35, 1, 'Virtual domain name'),
(70, 35, 2, 'Name der virtuellen Domain'),
(71, 36, 1, 'Save changes'),
(72, 36, 2, 'Änderungen speichern'),
(73, 37, 1, 'Edit'),
(74, 37, 2, 'Ändern'),
(75, 38, 1, 'Delete'),
(76, 38, 2, 'Löschen'),
(77, 39, 1, 'Virtual User Manager'),
(78, 39, 2, 'Verwaltung virtueller Benutzer'),
(79, 40, 1, 'Select a virtual domain:'),
(80, 40, 2, 'Virtuelle Domain auswählen:'),
(81, 41, 1, 'Select DomainMasters'),
(82, 41, 2, 'Domain Verwalter bestimmen'),
(83, 42, 1, 'Add new virtual user to selected domain'),
(84, 42, 2, 'Neuen virtuellen Benutzer hinzufügen'),
(85, 43, 1, 'DomainMaster?'),
(86, 43, 2, 'Domain Verwalter?'),
(87, 44, 1, 'Virtual users email address'),
(88, 44, 2, 'Benutzer Email Adresse'),
(89, 45, 1, 'Save DomainMasters'),
(90, 45, 2, 'Domain Verwalter speichern'),
(91, 46, 1, 'New virtual user'),
(92, 46, 2, 'Neuen Bemnutzer anlegen'),
(93, 47, 1, 'Name of virtual user:'),
(94, 47, 2, 'Benutzername:'),
(95, 48, 1, 'Password (default auto):'),
(96, 48, 2, 'Passwort (automatisch):'),
(97, 49, 1, 'Save new virtual user'),
(98, 49, 2, 'Neuen Benutzer speichern'),
(99, 50, 1, 'Create New password'),
(100, 50, 2, 'Neues Passwort erstellen'),
(101, 51, 2, 'Informationen zur Bedienung des Mail Managers'),
(102, 51, 1, 'Information on how to use Mail Manager'),
(103, 52, 2, 'Allgemein'),
(104, 52, 1, 'Common informations'),
(105, 53, 2, 'Mit diesem Interface können virtuelle Domains und deren Benutzer verwaltet werden.<br>Die Rolle des MailMasters berechtigt zum Anlegen, editieren und löschen von virtuellen Domains und deren Benutzer. Weiterhin kann dieser Benutzer DomainMasters bestimmen, die innerhalb ihrer Domain die Benutzer verwalten können. Somit kann die Administration einzelner Domains durch deren berchtigte Personen selbst erfolgen.<br><br>Die Software ist unter GPL - Lizenz veröffentlicht. Es wird keinerlei Garantie gewährt.'),
(106, 53, 1, 'With this interface virtual domains and th correspondending users ca be managed.<br>A user with the role of a MailMaster can create, edit or delete virtual domains and their users. He also can decide about who can manage the single domains in the role of a DomainMaster. So the administration of the single domains can be done by the owners of the domain.<br><br>This software is published under GPL license and comes without any warranty.'),
(107, 54, 2, 'Virtuelle Domains verwalten'),
(108, 54, 1, 'Managing virtual domains'),
(109, 55, 2, 'Zugang zur Domainverwaltung haben nur Benutzer mit dem Status MailMaster.<br><br>Beim Erstellen einer virtuellen Domain wird die Gültigkeit des eingegebenen Domainnamens standardmässig überprüft.<br>Sollte es dabei zu Problemen kommen, kann diese Überprüfung auch deaktiviert werden. Jedoch ist dabei auf eine korrekte Namensvergabe zu achten, da ansonsten die virtuelle Domain nicht funktionieren wird.<br><br>Erlaubte Zeichen sind a-z, A-Z, 0-9 und -. Die Mindeszahl der Zeichen vor dem Punkt beträgt 3, nach dem Punkt 2-3 Zeichen.<br><br>Bei Änderungen einer virtuellen Domain werden alle auf dieser Domain registrierten Email Adressen automatisch mitgeändert. Dasselbe gilt für das Löschen einer virtuellen Domain.<br>'),
(110, 55, 1, 'The usage of this section is permitted only to MailMasters.<br><br>When creating a new virtual domain, the given name is checked against the platform rules. If problems with the name appear the check can be disabled. If you disable the name check please check the correctness by yourself, otherwise the domain may not function correctly.<br><br>Allowed chars are a-z, A-Z, 0-9 and -. There have to be at least 3 chars before the dot 2-3 chars after the dot.<br><br>If a virtual domain is changed, all of the registered email adresses of this domain are changed too automatically. Also when a domain is deleted, alln users are deleted too.<br>'),
(111, 56, 2, 'Virtuelle Benutzer verwalten'),
(112, 56, 1, 'Manage virtual users'),
(113, 57, 2, 'Zugang zur Domainverwaltung haben Benutzer mit dem Status MailMaster oder DomainMaster, wobei ein DomainMaster auch mehrere Domains verwalten kann.<br><br>Um mit dem Benutzer Manager arbeiten zu können muss zuerst eine Domain ausgewählt werden. Danach können DomainMaster bestimmt, Benutzer angelegt, geändert oder gelöscht werden.<br><br>Eingegebene Namen und Passwörter werden jeweils auf ihre Gültigkeit überprüft.<br>Erlaubte Zeichen bei Namen sind a-z, A-Z, 0-9 . und -. Die erlaubte Anzahl der Zeichen beträgt 3 - 30.<br>Erlaubte Zeichen bei Passwörtern sind a-z, A-Z, 0-9 $ und @. Die erlaubte Anzahl der Zeichen beträgt 8 - 15.<br>Beim Erstellen und Editieren eines Benutzers wird jeweils ein generiertes Passwort vorgeschlagen, das jedoch überschrieben werden kann.'),
(114, 57, 1, 'Usage of this section is permitted to MailMasters and DomainMasters. One DomainMaster can manage 1 or more domains.<br><br>To work with the user manager first you have to select a virtual domain. After selection of a domain, you will be able to manage DomainMasters and the users of the selected domain. Users can be created, edited or deleted.<br><br>Given name and passwords will be checked against the rules of this platform.<br>Allowed chars for names are a-z, A-Z, 0-9 . and -. A name has to have between 3 and 30 chars.<br>Allowed chars for passwords are a-z, A-Z, 0-9 $ and @. A password has to have between 8 and 15 chars.<br>If you create or edit a virtual user, a generated password will be given. You can overwrite this password but still matching the rules.'),
(115, 58, 1, 'Sorry, no permission to this administration area.'),
(116, 58, 2, 'Kein Zutritt zu diesem Administrationsbereich'),
(117, 59, 1, 'No user with this data. Check your entries.'),
(118, 59, 2, 'Kein Benutzer mit diesen Daten. Überprüfen Sie Ihre Angaben.'),
(119, 60, 1, 'No password.'),
(120, 60, 2, 'Kain Passwort angegeben.'),
(121, 61, 1, 'No email adress.'),
(122, 61, 2, 'Keine Email Adresse angegeben.'),
(123, 62, 1, 'Manage virtual aliases'),
(124, 62, 2, 'Virtuelle Aliase verwalten'),
(125, 63, 1, 'Invalid email'),
(126, 63, 2, 'Ungültige Email Addresse.'),
(127, 64, 1, 'Invalid domain.'),
(128, 64, 2, 'Ungültige Domain.'),
(129, 65, 1, 'Invalid name in email.'),
(130, 65, 2, 'Ungültiger Name in der Email Adresse.'),
(131, 66, 1, 'You really want to delete this alias?'),
(132, 66, 2, 'Soll dieser Alias wirklich gelöscht werden?'),
(133, 67, 1, 'This section is permitted to every validated email user.<br><br>You can edit your username and change your password. The corresponding email addresses will be fixed recursivly.<br>You also can add, edit or delete virtual aliases. Every input is validated against the rules and changes are made recursivly.'),
(134, 67, 2, 'Dieser Bereich ist für alle registrierten Email Benutzer zugänglich.<br><br>Hier kann man seine Email Adresse ändern oder ein neues Passwort anlegen. Zusätzlich besteht die Möglichkeit Email Aliase (Weierleitungen) anzulegen, zu editieren oder zu löschen.<br>Alle Angaben werden auf ihre Gültigkeit überprüft.'),
(135, 68, 1, 'Select a virtual user'),
(136, 68, 2, 'Virtuellen Benutzer auswählen'),
(137, 69, 1, ' on domain '),
(138, 69, 2, ' in Domain '),
(139, 70, 1, 'Email alias'),
(140, 70, 2, 'Email alias'),
(141, 71, 1, 'Virtual aliases for '),
(142, 71, 2, 'Virtuelle Aliase für '),
(143, 72, 1, 'Add virtual alias'),
(144, 72, 2, 'Neuen Alias hinzufügen'),
(145, 73, 1, 'New alias'),
(146, 73, 2, 'Neuer Alias'),
(147, 74, 1, 'Save new alias'),
(148, 74, 2, 'Neuen Alias speichern'),
(149, 75, 1, 'Virtual user name'),
(150, 75, 2, 'Virtueller Benutzername'),
(151, 76, 1, 'Forwarded to'),
(152, 76, 2, 'Weiterleitung nach'),
(153, 77, 1, 'Email address'),
(154, 77, 2, 'Email Adresse'),
(155, 78, 1, 'Add forwarding'),
(156, 78, 2, 'Weiterleitung hinzufügen'),
(157, 79, 1, 'New forwarding'),
(158, 79, 2, 'Neue Weiterleitung'),
(159, 80, 1, 'Save new forwarding'),
(160, 80, 2, 'Neue Weiterleitung speichern'),
(161, 81, 1, 'Virtual alias'),
(162, 81, 2, 'Virtueller Alias'),
(163, 82, 1, 'User email'),
(164, 82, 2, 'Email Adresse'),
(165, 83, 1, 'New alias'),
(166, 83, 2, 'Neuer Alias'),
(167, 84, 1, 'Alias name'),
(168, 84, 2, 'Alias Name'),
(169, 85, 1, 'Emails forward to'),
(170, 85, 2, 'Emails weiterleiten nach'),
(171, 86, 1, 'Virtual aliases for '),
(172, 86, 2, 'Virtuelle Aliase für '),
(173, 87, 1, ' on virtual domain '),
(174, 87, 2, ' in Domain '),
(175, 88, 1, 'Really want to delete this email forwarding?'),
(176, 88, 2, 'Soll diese Weiterleitung wirklich gelöscht werden?'),
(177, 89, 1, 'This alias is already in use.'),
(178, 89, 2, 'Dieser Alias ist schon vergeben.'),
(179, 90, 1, 'Please insert an alias name.'),
(180, 90, 2, 'Kein Alias Name angegeben.');

INSERT INTO domain_admins ( id , domain_id , user_id )
VALUES (
NULL , '0', '1'
);" > /root/postfix-mysql.sql
